@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: blaze-html
-version: 0.5.0.0
-id: blaze-html-0.5.0.0-6cde58a627c0042ada4ce76f3d3dca1d
+version: 0.6.1.1
+id: blaze-html-0.6.1.1-d9a2e0519a92c20d0751dbc779791ce7
 
 license: BSD3
 copyright:
@@ -27,26 +27,27 @@ exposed-modules: Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
                  Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
                  Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
                  Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
-                 Text.Blaze.XHtml1.Transitional.Attributes
+                 Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
+                 Text.Blaze.XHtml5.Attributes
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/blaze-html-0.5.0.0
-library-dirs: /usr/local/lib/ghc/blaze-html-0.5.0.0
-hs-libraries: HSblaze-html-0.5.0.0
+import-dirs: /usr/local/lib/ghc/blaze-html-0.6.1.1
+library-dirs: /usr/local/lib/ghc/blaze-html-0.6.1.1
+hs-libraries: HSblaze-html-0.6.1.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         blaze-builder-0.2.1.4-cbacb369ecb80a55dd55bab68eb21ee1
-         blaze-markup-0.5.1.0-a7161cd8238b19f58c8aa6ab97b5b50f
-         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
-         text-0.11.2.3-6d44323283fc0f3935743a72b4424942
+depends: base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
+         blaze-builder-0.3.1.1-ac49b512143342e2370aead8ef93c70b
+         blaze-markup-0.5.1.5-2469a9388e0fb2943fc206e9c09e2bea
+         bytestring-0.10.0.2-fdb789c5db2e1ca48eb014403eee81b4
+         text-0.11.3.1-3fa3b4cb4ca4c0f49eeebe965c439ff9
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-blaze-html-0.5.0.0/html/blaze-html.haddock
-haddock-html: /usr/local/share/doc/hs-blaze-html-0.5.0.0/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-blaze-html-0.6.1.1/html/blaze-html.haddock
+haddock-html: /usr/local/share/doc/hs-blaze-html-0.6.1.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
